@@ -100,6 +100,7 @@ def test_serialization_full() -> None:
         'numpy_bool': np.array([True, True, False]),
         'numpy_matrix': np.array([[1, 2], [3, 4]]),
         'list_units': [1 * units.fg, 2 * units.fg],
+        'units_list': [1, 2] * units.fg,
         'list': [True, False, 'test', 1, None],
         'quantity': 5 * units.fg,
         'unit': units.fg,
@@ -127,6 +128,10 @@ def test_serialization_full() -> None:
             '!units[1 femtogram]',
             '!units[2 femtogram]',
         ],
+        'units_list': [
+            '!units[1 femtogram]',
+            '!units[2 femtogram]',
+        ],
         'list': [True, False, 'test', 1, None],
         'quantity': '!units[5 femtogram]',
         'unit': '!units[femtogram]',
@@ -148,6 +153,7 @@ def test_serialization_full() -> None:
         'numpy_bool': [True, True, False],
         'numpy_matrix': [[1, 2], [3, 4]],
         'list_units': [1 * units.fg, 2 * units.fg],
+        'units_list': [1 * units.fg, 2 * units.fg],
         'list': [True, False, 'test', 1, None],
         'quantity': 5 * units.fg,
         'unit': 1 * units.fg,
