@@ -1121,7 +1121,7 @@ def test_engine_run_for() -> None:
             f"process at path {path} did not complete"
 
 
-def emit_control() -> None:
+def test_set_branch_emit() -> None:
     run_time = 5
     # get the composer
     composer = PoQo({})
@@ -1130,7 +1130,8 @@ def emit_control() -> None:
     composite = composer.generate()
     exp = Engine(
         composite=composite,
-        store_emit={'on': [()]})
+        store_schema={'_emit': True}
+    )
     exp.update(run_time)
     data = exp.emitter.get_data()
     assert data[run_time]['bbb'] != {}, 'this emit should be on'
@@ -1140,7 +1141,8 @@ def emit_control() -> None:
     composite = composer.generate()
     exp = Engine(
         composite=composite,
-        store_emit={'off': [()]})
+        store_schema={'_emit': False}
+    )
     exp.update(run_time)
     data = exp.emitter.get_data()
     assert data[run_time]['bbb'] == {}, 'this emit should be off'
@@ -1150,23 +1152,34 @@ def emit_control() -> None:
     composite = composer.generate()
     exp = Engine(
         composite=composite,
-        store_emit={
-            'on': [('bbb', 'e2',)],
-        })
+        store_schema={'bbb': {'e2': {'_emit': True}}},
+    )
     exp.update(run_time)
     data = exp.emitter.get_data()
     assert data[run_time]['bbb']['e2'] != {}, 'this emit should be on'
     assert data[run_time]['ccc'] == {}, 'this emit should be off'
     print(pf(data))
 
-    # test store_emit with None
-    composite = composer.generate()
-    exp = Engine(
-        composite=composite,
-        store_emit={
-            'on': None,
-        })
-    exp.update(run_time)
+
+def test_add_new_state() -> None:
+    agent_id = '1'
+    composite = get_toy_transport_in_env_composite(agent_id=agent_id)
+    new_schema = {
+        'agents': {
+            agent_id: {
+                'extra': {'_emit': True, '_value': 1.0}}}}
+    experiment = Engine(
+        processes=composite.processes,
+        topology=composite.topology,
+        store_schema=new_schema,
+    )
+
+    assert experiment.state['agents', agent_id, 'extra'].get_value() == 1.0
+
+    total_time = 5
+    experiment.update(total_time)
+    timeseries = experiment.emitter.get_timeseries()
+    assert len(timeseries['agents'][agent_id]['extra']) == total_time + 1
 
 
 engine_tests = {
@@ -1189,7 +1202,8 @@ engine_tests = {
     '16': test_hyperdivision,
     '17': test_output_port,
     '18': test_engine_run_for,
-    '19': emit_control,
+    '19': test_set_branch_emit,
+    '20': test_add_new_state,
 }
 
 
