@@ -7,11 +7,8 @@ This is a toy example referenced in the documentation.
 """
 
 from vivarium.core.process import Process
-from vivarium.core.composition import (
-    simulate_process,
-)
+from vivarium.core.composition import simulate_process
 from vivarium.plots.simulation_output import plot_simulation_output
-from vivarium.processes.tree_mass import TreeMass
 from vivarium.library.units import units
 
 
@@ -24,50 +21,6 @@ class GlucosePhosphorylation(Process):
         'K_GLC': 4e-2,
     }
 
-    def __init__(self, initial_parameters=None):
-        parameters = GlucosePhosphorylation.defaults
-        parameters.update(initial_parameters)
-        super(GlucosePhosphorylation, self).__init__(
-            parameters)
-
-    def next_update(self, timestep, states):
-        # Get concentrations from state
-        cytoplasm = states['cytoplasm']
-        nucleoside_phosphates = states['nucleoside_phosphates']
-        hk = cytoplasm['HK']
-        glc = cytoplasm['GLC']
-        atp = nucleoside_phosphates['ATP']
-
-        # Get kinetic parameters
-        k_cat = self.parameters['k_cat']
-        k_atp = self.parameters['K_ATP']
-        k_glc = self.parameters['K_GLC']
-
-        # Compute reaction rate with michaelis-menten equation
-        rate = k_cat * hk * glc * atp / (
-            k_glc * k_atp + k_glc * atp + k_atp * glc + glc * atp)
-
-        # Compute concentration changes from rate and timestep
-        delta_glc = -rate * timestep
-        delta_atp = -rate * timestep
-        delta_g6p = rate * timestep
-        delta_adp = rate * timestep
-
-        # Compile changes into an update
-        update = {
-            'cytoplasm': {
-                'GLC': delta_glc,
-                'G6P': delta_g6p,
-                # We exclude HK because it doesn't change
-            },
-            'nucleoside_phosphates': {
-                'ATP': delta_atp,
-                'ADP': delta_adp,
-            },
-        }
-
-        return update
-
     def ports_schema(self):
         return {
             'cytoplasm': {
@@ -106,34 +59,56 @@ class GlucosePhosphorylation(Process):
                     '_emit': True,
                 }
             },
-            'global': {
+        }
+
+    def next_update(self, timestep, states):
+        # Get concentrations from state
+        cytoplasm = states['cytoplasm']
+        nucleoside_phosphates = states['nucleoside_phosphates']
+        hk = cytoplasm['HK']
+        glc = cytoplasm['GLC']
+        atp = nucleoside_phosphates['ATP']
+
+        # Get kinetic parameters
+        k_cat = self.parameters['k_cat']
+        k_atp = self.parameters['K_ATP']
+        k_glc = self.parameters['K_GLC']
+
+        # Compute reaction rate with michaelis-menten equation
+        rate = k_cat * hk * glc * atp / (
+            k_glc * k_atp + k_glc * atp + k_atp * glc + glc * atp)
+
+        # Compute concentration changes from rate and timestep
+        delta_glc = -rate * timestep
+        delta_atp = -rate * timestep
+        delta_g6p = rate * timestep
+        delta_adp = rate * timestep
+
+        # Compile changes into an update
+        update = {
+            'cytoplasm': {
+                'GLC': delta_glc,
+                'G6P': delta_g6p,
+                # We exclude HK because it doesn't change
+            },
+            'nucleoside_phosphates': {
+                'ATP': delta_atp,
+                'ADP': delta_adp,
             },
         }
 
-    def derivers(self):
-        # We instantiate TreeMass to make sure it's added to the deriver
-        # registry.
-        TreeMass()
-        return {
-            'my_deriver': {
-                'deriver': 'mass_deriver',
-                'port_mapping': {
-                    'global': 'global',
-                },
-                'config': {},
-            },
-        }
+        return update
 
 
 if __name__ == '__main__':
     parameters = {
         'k_cat': 1.5,
+        'time_step': 0.1,
     }
     my_process = GlucosePhosphorylation(parameters)
 
     settings = {
         'total_time': 10,
-        'timestep': 0.1,
     }
     timeseries = simulate_process(my_process, settings)
     plot_simulation_output(timeseries, {}, './')
